@@ -59,31 +59,31 @@ class DingDingPlugin(NotificationPlugin):
             "http://web-middle.ruibogyl.work/sentry/findIssueTargetUrl",
             {"id": issue_id},
             headers={}
-        ).json()
-        print issue_data["data"]["url"]
-        response = requests.get(
-            "http://web-middle.ruibogyl.work/sentry/getDingDingAssignee",
-            {"url": issue_data["data"]["url"]},
-            headers={}
-        ).json()
-        print response["data"]["phone"]
+        )
+        print issue_data
+        # response = requests.get(
+        #     "http://web-middle.ruibogyl.work/sentry/getDingDingAssignee",
+        #     {"url": issue_data["data"]["url"]},
+        #     headers={}
+        # ).json()
+        # print response["data"]["phone"]
         data = {
             "msgtype": "markdown",
             "markdown": {
                 "title": title,
-                "text": "#### {title} \n > {message} \n [点击查看问题]({event_url}) \n @{phone}".format(
+                "text": "#### {title} \n > {message} \n [点击查看问题]({event_url}) \n ".format(
                     title=title,
                     message=event.message,
                     event_url=event_url,
-                    phone=response["data"]["phone"],
+                    # phone=response["data"]["phone"],
                 ),
             },
-            "at": {
-                "atMobiles": [
-                    response["phone"]
-                ],
-                "isAtAll": False
-            }
+            # "at": {
+            #     "atMobiles": [
+            #         response["phone"]
+            #     ],
+            #     "isAtAll": False
+            # }
         }
         requests.post(
             url=send_url,
